summaryrefslogtreecommitdiff
path: root/test
diff options
context:
space:
mode:
authorTiejunZhou <[email protected]>2023-04-17 09:40:59 +0800
committerGitHub <[email protected]>2023-04-17 09:40:59 +0800
commit4c4547d5d5a837fbc5ed0f8ba3315792da732f2a (patch)
tree88abed1c4428c8dd66485fd441219bf215685df0 /test
parent0d308c7ae62085e68c7aa0a516f664c39e9a8407 (diff)
Fix path to test reports in pipeline (#247)
* Fix path to test reports in pipeline * Fix test case when CPU starves, the thread 2 can run 14 ronuds.
Diffstat (limited to 'test')
-rw-r--r--test/tx/regression/threadx_event_flag_suspension_timeout_test.c12
1 files changed, 10 insertions, 2 deletions
diff --git a/test/tx/regression/threadx_event_flag_suspension_timeout_test.c b/test/tx/regression/threadx_event_flag_suspension_timeout_test.c
index 5bdc6c78..c689c755 100644
--- a/test/tx/regression/threadx_event_flag_suspension_timeout_test.c
+++ b/test/tx/regression/threadx_event_flag_suspension_timeout_test.c
@@ -179,8 +179,16 @@ UINT status;
tx_thread_sleep(63);
/* Check the run counters. */
- if (((thread_1_counter != 32) && (thread_1_counter != 33)) || /* Depending on the starting time, thread 1 can run either 32 or 33 rounds. */
- (thread_2_counter != 13))
+ if (((thread_1_counter != 32)
+#ifdef __linux__
+ && (thread_1_counter != 33) /* Depending on the starting time, thread 1 can run either 32 or 33 rounds. */
+#endif
+ ) ||
+ ((thread_2_counter != 13)
+#ifdef __linux__
+ && (thread_2_counter != 14) /* When CPU starves, the thread 2 can run 14 ronuds. */
+#endif
+ ))
{
/* Event flag error. */